@@ -23,8 +23,8 @@ INGEST_STATUS = {
 def process_caris(infile, outpath, file_name):
     with scoped_logger(__name__) as log:
         os.makedirs(f"{outpath}", exist_ok=True)
-        result = process_caris_json(infile, outpath, INGEST_STATUS)
+        result = process_caris_json(infile, outpath, file_name, INGEST_STATUS, log)
         if "somatic_vcf" in result:
-            process_caris_vcf(result["somatic_vcf"], outpath, file_name)
+            process_caris_vcf(result["somatic_vcf"], outpath, file_name, log)
         if "germline_vcf" in result:
-            process_caris_vcf(result["germline_vcf"], outpath, file_name)
+            process_caris_vcf(result["germline_vcf"], outpath, file_name, log)
