@@ -12,6 +12,7 @@ from ingestion.foundation.util.ga4gh import (
     get_test_yml,
     get_mrn,
     get_trf,
+    get_non_human_content,
 )
 from ingestion.foundation.util.vcf_etl import vcf_etl, transform_scientific_notation_in_af
 
@@ -182,9 +183,9 @@ def test_yml():
                 "msi": "stable",
                 "tmb": "low",
                 "tmbScore": 0.73,
-                "nhcOrganism": "HHV-4",
-                "nhcReadsPerMil": 14.0,
-                "nhcStatus": "unknown",
+                "nonHumanContent": [
+                    {"nhcOrganism": "HHV-4", "nhcReadsPerMil": 14.0, "nhcStatus": "unknown"}
+                ],
             }
         ]
     }
@@ -436,7 +437,6 @@ def test_yml_with_no_biomarkers():
         ".lifeomic/foundation",
     )
 
-    print(yml)
     assert yml == {
         "tests": [
             {
@@ -575,9 +575,11 @@ def test_yml_with_multiple_non_human_content():
                 "msi": "stable",
                 "tmb": "low",
                 "tmbScore": 0.73,
-                "nhcOrganism": ["HHV-4", "HPV-18", "HHV-4"],
-                "nhcReadsPerMil": [14.0, 17.0, 92.0],
-                "nhcStatus": ["unknown", "unknown", "unknown"],
+                "nonHumanContent": [
+                    {"nhcOrganism": "HHV-4", "nhcReadsPerMil": 14.0, "nhcStatus": "unknown"},
+                    {"nhcOrganism": "HPV-18", "nhcReadsPerMil": 17.0, "nhcStatus": "unknown"},
+                    {"nhcOrganism": "HHV-4", "nhcReadsPerMil": 92.0, "nhcStatus": "unknown"},
+                ],
             }
         ]
     }
@@ -627,3 +629,30 @@ def test_get_ordering_md():
 
     existing_md_both = get_ordering_md({"OrderingMD": "Smith, John"}, "9706")
     assert existing_md_both == ["Smith, John", "9706"]
+
+
+def test_get_non_human_content():
+    single_nhc = get_non_human_content(
+        [{"@organism": "HHV-4", "@reads-per-million": "14", "@status": "unknown"}]
+    )
+    assert single_nhc == [{"nhcOrganism": "HHV-4", "nhcReadsPerMil": 14, "nhcStatus": "unknown"}]
+
+    multiple_nhc = get_non_human_content(
+        [
+            {"@organism": "HHV-4", "@reads-per-million": "14", "@status": "unknown"},
+            {"@organism": "HPV-4", "@reads-per-million": "24", "@status": "unknown"},
+        ]
+    )
+    assert multiple_nhc == [
+        {"nhcOrganism": "HHV-4", "nhcReadsPerMil": 14.0, "nhcStatus": "unknown"},
+        {"nhcOrganism": "HPV-4", "nhcReadsPerMil": 24.0, "nhcStatus": "unknown"},
+    ]
+
+    no_organism = get_non_human_content([{"@reads-per-million": "14", "@status": "unknown"}])
+    assert no_organism == [{"nhcOrganism": "unknown", "nhcReadsPerMil": 14, "nhcStatus": "unknown"}]
+
+    no_rpm = get_non_human_content([{"@organism": "HHV-4", "@status": "unknown"}])
+    assert no_rpm == [{"nhcOrganism": "HHV-4", "nhcReadsPerMil": 0.0, "nhcStatus": "unknown"}]
+
+    no_status = get_non_human_content([{"@organism": "HHV-4", "@reads-per-million": "14"}])
+    assert no_status == [{"nhcOrganism": "HHV-4", "nhcReadsPerMil": 14, "nhcStatus": "unknown"}]
